import math


def radius_to_circumference(radius: float) -> float:
    """Calculates circumference using radius.

    Args:
        radius (float): radius

    Returns:
        float: circumference
    """
    return 2 * math.pi * radius

def diameter_to_circumference(diameter: float) -> float:
    """Calculates circumference using diameter

    Args:
        diameter (float): diameter

    Returns:
        float: circumference
    """
    return 2 * math.pi * diameter / 2




def mm_to_cm(mm: float) -> float:
    return mm / 10

def mm_to_m(mm: float) -> float:
    return mm / 1000

def mm_to_inch(mm: float) -> float:
    return mm / 25.4


def cm_to_mm(cm: float):
    return cm * 10

def cm_to_inch(cm: float) -> float:
    return cm / 2.54

def cm_to_m(cm: float) -> float:
    return cm / 100


def m_to_mm(m: float) -> float:
    return m * 1000


def inch_to_mm(inch: float) -> float:
    return inch * 25.4

def inch_to_cm(inch: float) -> float:
    return inch * 2.54

def inch_to_m(inch: float) -> float:
    return inch / 39.37


def kmph_to_mph(kmph: float) -> float:
    return kmph / 1.609

def mph_to_kmph(mph: float) -> float:
    return mph * 1.609


def rpm_to_rps(rpm: float) -> float:
    return rpm / 60

def rps_to_rpm(rps: float) -> float:
    return rps * 60




import autoCal.helperConverters as hc
import autoCal.unitConverters as uc

def wheel_rpm_to_kmph(wheel_rpm: float, tyre_size: float) -> float:
    """Calculates speed in km/h from wheel rpm

    Args:
        wheel_rpm (float): RPM of wheel
        tyre_size (float): diameter of tyre in meters

    Returns:
        float: Speed in km/h
    """
    meters_ph = wheel_rpm * 60 * hc.diameter_to_circumference(tyre_size)
    return meters_ph / 1000

def wheel_rpm_to_mph(wheel_rpm: float, tyre_size: float) -> float:
    """Calculates speed in miles per hour from wheel rpm

    Args:
        wheel_rpm (float): RPM of wheel
        tyre_size (float): diameter of tyre in meters

    Returns:
        float: speed in miles per hour
    """
    kmph = wheel_rpm_to_kmph(wheel_rpm, tyre_size)
    return uc.kmph_to_mph(kmph)

def kmph_to_wheel_rpm(kmph: float, tyre_size: float) -> float:
    """Calculates wheel rpm from speed in kmph

    Args:
        kmph (float): speed in kmph
        tyre_size (float): diameter of tyre in meters

    Returns:
        float: wheel rpm
    """
    circumference = hc.diameter_to_circumference(tyre_size)
    meter_per_min = (kmph * 1000) / 60
    return meter_per_min / circumference

def mph_to_wheel_rpm(mph: float, tyre_size: float) -> float:
    """Calculates wheel rpm from speed in miles per hour

    Args:
        mph (float): speed in miles per hour
        tyre_size (float): diameter of tyre in meters

    Returns:
        float: wheel rpm
    """
    kmph = uc.mph_to_kmph(mph)
    return kmph_to_wheel_rpm(kmph, tyre_size)

def wheel_rpm_to_time_required_for_one_wheel_rotation(rpm: float) -> float:
    """Calculates time required for one wheel rotation from rpm

    Args:
        rpm (float): rpm of wheel

    Returns:
        float: time (seconds) required for one wheel rotation
    """
    return 60 / rpm

def kmph_to_time_required_for_one_wheel_rotation(kmph: float, tyre_size: float) -> float:
    """Calculates time required for one wheel rotation from speed in kmph

    Args:
        kmph (float): speed in kmph
        tyre_size (float): diameter of tyre in meters

    Returns:
        float: time (seconds) required for one wheel rotation
    """
    rpm = kmph_to_wheel_rpm(kmph, tyre_size)
    return wheel_rpm_to_time_required_for_one_wheel_rotation(rpm)

def mph_to_time_required_for_one_wheel_rotation(mph: float, tyre_size: float) -> float:
    """Calculates time required for one wheel rotation from speed in miles per hour

    Args:
        mph (float): speed in miles per hour
        tyre_size (float): diameter of tyre in meters

    Returns:
        float: time (seconds) required for one wheel rotation
    """
    rpm = mph_to_wheel_rpm(mph, tyre_size)
    return wheel_rpm_to_time_required_for_one_wheel_rotation(rpm)


import autoCal.speedCalculations as sc


def motor_rpm_to_kmph(motor_rpm: float, tyre_size: float, drivetrain_ratio: float) -> float:
    """Calculates the speed of a motor in km/h from motor rpm and drivetrain ratio.

    Args:
        motor_rpm (float): motor RPM
        tyre_size (float): size of tyre in meters
        drivetrain_ratio (float): gear ratio

    Returns:
        float: return speed in km/h
    """
    wheel_rpm = motor_rpm / drivetrain_ratio
    return sc.wheel_rpm_to_kmph(wheel_rpm, tyre_size)

def motor_rpm_to_mph(motor_rpm: float, tyre_size: float, drivetrain_ratio: float) -> float:
    """Calculates the speed of a motor in mph from motor rpm and drivetrain ratio.

    Args:
        motor_rpm (float): motor RPM
        tyre_size (float): size of tyre in meters
        drivetrain_ratio (float): gear ratio

    Returns:
        float: returns speed in mph
    """
    wheel_rpm = motor_rpm / drivetrain_ratio
    return sc.wheel_rpm_to_mph(wheel_rpm, tyre_size)

def kmph_to_motor_rpm(kmph: float, tyre_size: float, drivetrain_ratio: float) -> float:
    """Calculates the motor rpm from speed in km/h.

    Args:
        motor_rpm (float): motor RPM
        tyre_size (float): size of tyre in meters
        drivetrain_ratio (float): gear ratio

    Returns:
        float: returns speed in RPM
    """
    wheel_rpm = sc.kmph_to_wheel_rpm(kmph, tyre_size)
    return wheel_rpm * drivetrain_ratio

def mph_to_motor_rpm(mph: float, tyre_size: float, drivetrain_ratio: float) -> float:
    """Calculates the motor RPM from speed in mph.

    Args:
        motor_rpm (float): motor RPM
        tyre_size (float): size of tyre in meters
        drivetrain_ratio (float): gear ratio

    Returns:
        float: returns speed in RPM
    """
    wheel_rpm = sc.mph_to_wheel_rpm(mph, tyre_size)
    return wheel_rpm * drivetrain_ratio

def wheel_rpm_to_motor_rpm(wheel_rpm: float, drivetrain_ratio: float) -> float:
    """Calculates the motor RPM from wheel RPM;

    Args:
        wheel_rpm (float): RPM of wheel
        drivetrain_ratio (float): gear ratio

    Returns:
        float: returns RPM of motor
    """
    return wheel_rpm * drivetrain_ratio

def motor_rpm_to_wheel_rpm(motor_rpm: float, drivetrain_ratio: float) -> float:
    """Calculates the wheel RPM from motor rpm.

    Args:
        motor_rpm (float): motor RPM
        drivetrain_ratio (float): gear ratio

    Returns:
        float: returns RPM of wheel
    """
    return motor_rpm / drivetrain_ratio

def motor_rpm_to_one_motor_rotation_time(motor_rpm: float) -> float:
    """Calculates the time required for motor to complete one rotation.

    Args:
        motor_rpm (float): RPM of motor

    Returns:
        float: returns time in seconds
    """
    return 60 / motor_rpm

def wheel_rpm_to_one_motor_rotation_time(wheel_rpm: float, drivetrain_ratio: float) -> float:
    """Calculates the time required for motor to complete one rotation.

    Args:
        wheel_rpm (float): RPM of wheel

    Returns:
        float: returns time in seconds
    """
    motor_rpm = wheel_rpm_to_motor_rpm(wheel_rpm, drivetrain_ratio)
    return 60 / motor_rpm


def get_hall_events_per_motor_rotation(pole_pairs: int) -> float:
    """Calculates the number of hall events in one rotation of motor.

    Args:
        pole_pairs (int): number of pole pairs

    Returns:
        float: number of hall events
    """
    return pole_pairs * 6

def get_hall_events_per_wheel_rotation(pole_pairs: int, drivetrain_ratio: float) -> float:
    """Calculates the number of hall events in one rotation of wheel.

    Args:
        pole_pairs (int): number of pole pairs
        drivetrain_ratio (float): drivetrain ratio

    Returns:
        float: number of hall events
    """
    return get_hall_events_per_motor_rotation(pole_pairs) * drivetrain_ratio

def get_hall_event_interval(motor_rpm: float, pole_pairs: int) -> float:
    """Calculates the time interval between two hall events.

    Args:
        motor_rpm (float): RPM of motor
        pole_pairs (int): number of pole pairs

    Returns:
        float: returns time interval in seconds
    """
    T = motor_rpm_to_one_motor_rotation_time(motor_rpm)
    hall_event_count = get_hall_events_per_motor_rotation(pole_pairs)
    return T / hall_event_count

def get_hall_events_per_second(motor_rpm: float, pole_pairs: int) -> float:
    """calculates the number of hall events per second

    Args:
        motor_rpm (float): RPM of motor
        pole_pairs (int): number of pole pairs

    Returns:
        float: returns number of hall events
    """
    rps = motor_rpm / 60
    hall_event_count = get_hall_events_per_motor_rotation(pole_pairs)
    return hall_event_count * rps

def get_hall_events_per_minute(motor_rpm: float, pole_pairs: float) -> float:
    """Calculates the number of hall events per minute

    Args:
        motor_rpm (float): RPM of motor
        pole_pairs (float): number of pole pairs

    Returns:
        float: returns the number of hall events
    """
    hall_event_count = get_hall_events_per_motor_rotation(pole_pairs)
    return hall_event_count * motor_rpm





from setuptools import setup, find_packages
import codecs
import os

VERSION = '0.0.4'
DESCRIPTION = 'Collection of automotive calculations'
LONG_DESCRIPTION = 'This repository provides a collection of mathematical formulas commonly used in the automotive industry, with a particular focus on Brushless DC (BLDC) motors.'

# Setting up
setup(
    name="autoCal",
    version=VERSION,
    author="GladsonThomas",
    author_email="<gladson.thomas.official@gmail.com>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    install_requires=[],
    keywords=['python', 'calculations', 'automotive', 'EV', 'BLDC'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)